@@ -21,7 +21,11 @@ impl Exchange {
     /// Create a new Exchange with the desired config and whether to use candles as infomation source
     pub fn new(config: Config) -> Exchange {
         assert!(config.leverage > 0.0);
-        let account = Account::new(config.leverage, config.starting_balance, config.futures_type);
+        let account = Account::new(
+            config.leverage,
+            config.starting_balance,
+            config.futures_type,
+        );
         let validator = Validator::new(config.fee_maker, config.fee_taker, config.futures_type);
         Exchange {
             config,
@@ -102,7 +106,10 @@ impl Exchange {
 
     /// Execute a market order
     fn execute_market(&mut self, side: Side, amount: f64) {
-      debug!("exchange: execute_market: side: {:?}, amount: {}", side, amount);
+        debug!(
+            "exchange: execute_market: side: {:?}, amount: {}",
+            side, amount
+        );
 
         let price: f64 = match side {
             Side::Buy => self.ask,
@@ -115,8 +122,7 @@ impl Exchange {
             FuturesType::Inverse => fee /= price,
         }
         self.account.deduce_fees(fee);
-        self.account
-            .change_position(side, amount, price);
+        self.account.change_position(side, amount, price);
     }
 
     /// Execute a limit order, once triggered
@@ -130,8 +136,7 @@ impl Exchange {
             FuturesType::Inverse => fee /= price,
         }
         self.account.deduce_fees(fee);
-        self.account
-            .change_position(side, amount, price);
+        self.account.change_position(side, amount, price);
     }
 
     /// Perform a liquidation of the account
